@@ -4,7 +4,7 @@
 
 package Mesoderm;
 {
-  $Mesoderm::VERSION = '0.121140';
+  $Mesoderm::VERSION = '0.122120';
 }
 use Moose;
 
@@ -84,16 +84,6 @@ sub _build__role_map {
 sub table_components {
   my ($self, $table) = @_;
   my @comp = qw(Core);
-  my ($pk) = grep { $_->type eq 'PRIMARY KEY' } $table->get_indices;
-  if ($pk ||= $table->primary_key) {
-    push @comp, 'PK::Auto' if grep { $table->get_field($_)->is_auto_increment } $pk->fields;
-  }
-  else {
-    warn $table->name," has no PRIMARY KEY\n";
-    foreach my $k ($table->get_constraints) {
-      warn join " ", "",$k->type,$k->name,"(",$k->fields,")\n";
-    }
-  }
   push @comp, 'InflateColumn::DateTime'
     if grep { $_->data_type =~ /^(DATE|DATETIME|TIMESTAMP)$/i } $table->get_fields;
   return @comp;
@@ -316,10 +306,12 @@ sub produce {
 
   foreach my $t ($schema->get_tables) {
     foreach my $i ($t->get_indices) {
+      $i->fields(grep { s/\(\d+\)//; 1 } $i->fields);    # remove column prefix length
       $t->drop_index($i->name) if $self->_ignore_index($i);
     }
 
     foreach my $c ($t->get_constraints) {
+      $c->fields(grep { s/\(\d+\)//; 1 } $c->fields);    # remove column prefix length
       next if $c->type ne 'FOREIGN KEY' or $self->_ignore_constraint($c);
       if (my $r1 = $self->build_relationship($c)) {
         unless ($self->ignore_relationship($r1)) {
@@ -431,6 +423,7 @@ sub _dump_data {
   local $Data::Dumper::Indent    = 1;
   local $Data::Dumper::Quotekeys = 0;
   local $Data::Dumper::Sortkeys  = 1;
+  local $Data::Dumper::Deepcopy  = 1;
   my $data = Data::Dumper::Dumper(shift);
   if (my $indent = shift) {
     $data =~ s/^/$indent/mg;
@@ -546,7 +539,8 @@ sub write_preamble {
   print $fh "#\n";
   print $fh "# *** DO NOT EDIT THIS FILE ***\n";
   printf $fh "# Generated on %s UTC, by\n", scalar gmtime();
-  local ($Mesoderm::VERSION) = (0) unless defined $Mesoderm::VERSION;
+  local ($Mesoderm::VERSION)    # hide from Module::Metadata
+    = (0) unless defined $Mesoderm::VERSION;
   foreach my $class ($self->meta->linearized_isa) {
     my $version = $class->VERSION;
     $version = 'undef' unless defined $version;
@@ -623,7 +617,7 @@ Mesoderm - Schema class scaffold generator for DBIx::Class
 
 =head1 VERSION
 
-version 0.121140
+version 0.122120
 
 =head1 SYNOPSIS
 
